==> blue-prints-0.0.3.tar.gz: blue-prints-0.0.3/README.md <==
[![Run Tests](https://github.com/Blueprints-org/blueprints/actions/workflows/test.yaml/badge.svg)](https://github.com/Blueprints-org/blueprints/actions/workflows/test.yaml)
[![Documentation Status](https://readthedocs.org/projects/blue-prints/badge/?version=latest)](https://blueprints.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/Blueprints-org/blueprints/branch/main/graph/badge.svg?token=vwYQBShr9q)](https://codecov.io/gh/Blueprints-org/blueprints)
[![PyPI](https://img.shields.io/pypi/v/blue-prints?color=green)](https://pypi.org/project/blue-prints/)
[![GitHub](https://img.shields.io/github/license/Blueprints-org/blueprints?color=green)](https://github.com/Blueprints-org/blueprints/blob/main/LICENSE)
[![Python versions](https://img.shields.io/badge/python-3.10%20%7C%203.11-blue?style=flat&logo=python)](https://badge.fury.io/py/blueprints)



<picture>
  <source media="(prefers-color-scheme: dark)" srcset="docs/source/_static/blueprints_banner.png">
  <source media="(prefers-color-scheme: light)" srcset="docs/source/_static/blueprints_banner.png">
  <img alt="blueprints banner" src="docs/source/_static/blueprints_banner.png">
</picture>

Welcome to Blueprints, the cornerstone repository for civil engineering professionals and enthusiasts alike. Blueprints is a collaborative, open-source initiative designed to serve as a comprehensive library of code, tools, and best practices, aiming to streamline and innovate the workflows within the built environment sector.

## Vision

Our vision with Blueprints is to create an accessible, reliable, and community-driven resource that supports engineers, and developers in their daily challenges. By harnessing the collective expertise of the industry, Blueprints strives to pave the way for a future where collaboration and open source can drive the field of civil engineering to new heights.

## Mission

Our mission is to:

- Foster a community where sharing knowledge and best practices is the norm, not the exception.
- Provide a solid foundation of code and documentation that adheres to the highest quality standards (100% code coverage).
- Offer a robust suite of tools and libraries that encapsulate common and advanced engineering tasks.

## Installation

For the last release:

```shell
pip install blue-prints
```

For the actively developed version:

```shell
pip install git+https://github.com/Blueprints-org/blueprints.git
```
Documentation is available at [blueprints.readthedocs.io](https://blueprints.readthedocs.io/en/latest/).

## Quick Reference to Blueprint's Objects

This table serves as a quick navigator to the key elements of the code within Blueprints, offering immediate links to its equations, tables, and
figures for streamlined access and reference.

| Document                    | Description                                                                                        |                             Formulas                             |                            Tables                            |                            Figures                             |
|:----------------------------|:---------------------------------------------------------------------------------------------------|:----------------------------------------------------------------:|:------------------------------------------------------------:|:--------------------------------------------------------------:|
| NEN-EN 1992-1-1+C2:2011     | Eurocode 2: Design of concrete structures – Part 1-1: General rules and rules for buildings        | [304](docs/source/codes/eurocode/ec2_1992_1_1_2011/formulas.md) | [38](docs/source/codes/eurocode/ec2_1992_1_1_2011/tables.md) | [104](docs/source/codes/eurocode/ec2_1992_1_1_2011/figures.md) |
| NEN-EN 1993-1-1+C2+A1:2016  | Eurocode 3: Design of steel structures – Part 1-1: General rules and rules for buildings           | [108](docs/source/codes/eurocode/ec3_1993_1_1_2016/formulas.md) | [20](docs/source/codes/eurocode/ec3_1993_1_1_2016/tables.md) | [28](docs/source/codes/eurocode/ec3_1993_1_1_2016/figures.md)  |
| NEN-EN 1997-1+C1+A1:2016    | Eurocode 7: Geotechnical design - Part 1: General rules                                            |  [102](docs/source/codes/eurocode/ec7_1997_1_2016/formulas.md)  |  [11](docs/source/codes/eurocode/ec7_1997_1_2016/tables.md)  |  [25](docs/source/codes/eurocode/ec7_1997_1_2016/figures.md)   |

## Contributing

Contributions are very welcome. To learn more, see the [Contributor Guide](CONTRIBUTING.md).

## License

Blueprints is free and open source software. Distributed under the terms of the [LGPL-2.1 license](LICENSE).

## Support

If you have found a bug 🐛, or have a feature request ✨, raise an issue on the
GitHub [issue tracker](https://github.com/Blueprints-org/blueprints/issues).
Alternatively you can get support on the [discussions](https://github.com/orgs/Blueprints-org/discussions) page.

## Disclaimer

Blueprints is an open source engineering tool that continues to benefit from the collaboration of many contributors. Although efforts have been
made to ensure the that relevant engineering theories have been correctly implemented, it remains the user's responsibility to confirm and accept
the output. Refer to the [license](LICENSE) for clarification of the conditions of use.

==> blue-prints-0.0.4.tar.gz: blue-prints-0.0.4/README.md <==
[![Run Tests](https://github.com/Blueprints-org/blueprints/actions/workflows/test.yaml/badge.svg)](https://github.com/Blueprints-org/blueprints/actions/workflows/test.yaml)
[![Read the Docs](https://img.shields.io/readthedocs/blueprints?logo=readthedocs&label=Read%20the%20docs&link=https%3A%2F%2Fblueprints.readthedocs.io%2Fen%2Flatest%2F)](https://blueprints.readthedocs.io/en/latest/)
[![codecov](https://codecov.io/gh/Blueprints-org/blueprints/branch/main/graph/badge.svg?token=vwYQBShr9q)](https://codecov.io/gh/Blueprints-org/blueprints)
[![PyPI](https://img.shields.io/pypi/v/blue-prints?color=green)](https://pypi.org/project/blue-prints/)
[![GitHub](https://img.shields.io/github/license/Blueprints-org/blueprints?color=green)](https://github.com/Blueprints-org/blueprints/blob/main/LICENSE)
[![Python versions](https://img.shields.io/badge/python-3.10%20%7C%203.11-blue?style=flat&logo=python)](https://badge.fury.io/py/blueprints)



<picture>
  <source media="(prefers-color-scheme: dark)" srcset="docs/source/_static/blueprints_banner.png">
  <source media="(prefers-color-scheme: light)" srcset="docs/source/_static/blueprints_banner.png">
  <img alt="blueprints banner" src="docs/source/_static/blueprints_banner.png">
</picture>

Welcome to Blueprints, the cornerstone repository for civil engineering professionals and enthusiasts alike. Blueprints is a collaborative, open-source initiative designed to serve as a comprehensive library of code, tools, and best practices, aiming to streamline and innovate the workflows within the built environment sector.

## Vision

Our vision with Blueprints is to create an accessible, reliable, and community-driven resource that supports engineers, and developers in their daily challenges. By harnessing the collective expertise of the industry, Blueprints strives to pave the way for a future where collaboration and open source can drive the field of civil engineering to new heights.

## Mission

Our mission is to:

- Foster a community where sharing knowledge and best practices is the norm, not the exception.
- Provide a solid foundation of code and documentation that adheres to the highest quality standards (100% code coverage).
- Offer a robust suite of tools and libraries that encapsulate common and advanced engineering tasks.

## Installation

For the last release:

```shell
pip install blue-prints
```

For the actively developed version:

```shell
pip install git+https://github.com/Blueprints-org/blueprints.git
```
Documentation is available at [blueprints.readthedocs.io](https://blueprints.readthedocs.io/en/latest/).

## Quick Reference to Blueprint's Objects

This table serves as a quick navigator to the key elements of the code within Blueprints, offering immediate links to its equations, tables, and
figures for streamlined access and reference.

| Document                   | Description                                                                                 |                            Formulas                             |                            Tables                            |                            Figures                             |
|:---------------------------|:--------------------------------------------------------------------------------------------|:---------------------------------------------------------------:|:------------------------------------------------------------:|:--------------------------------------------------------------:|
| NEN-EN 1992-1-1+C2:2011    | Eurocode 2: Design of concrete structures – Part 1-1: General rules and rules for buildings | [304](docs/source/codes/eurocode/ec2_1992_1_1_2011/formulas.md) | [38](docs/source/codes/eurocode/ec2_1992_1_1_2011/tables.md) | [104](docs/source/codes/eurocode/ec2_1992_1_1_2011/figures.md) |
| NEN-EN 1993-1-1+C2+A1:2016 | Eurocode 3: Design of steel structures – Part 1-1: General rules and rules for buildings    | [108](docs/source/codes/eurocode/ec3_1993_1_1_2016/formulas.md) | [20](docs/source/codes/eurocode/ec3_1993_1_1_2016/tables.md) | [28](docs/source/codes/eurocode/ec3_1993_1_1_2016/figures.md)  |
| NEN 9997-1+C2:2017         | Eurocode 7: Geotechnical design of structures - Part 1: General rules                       | [88](docs/source/codes/eurocode/nen_9997_1_c2_2017/formulas.md) |  [11](docs/source/codes/eurocode/nen_9997_1_c2_2017/tables.md)  |  [25](docs/source/codes/eurocode/nen_9997_1_c2_2017/figures.md)   |

## Contributing

Contributions are very welcome. To learn more, see the [Contributor Guide](CONTRIBUTING.md).

## License

Blueprints is free and open source software. Distributed under the terms of the [LGPL-2.1 license](LICENSE).

## Support

If you have found a bug 🐛, or have a feature request ✨, raise an issue on the
GitHub [issue tracker](https://github.com/Blueprints-org/blueprints/issues).
Alternatively you can get support on the [discussions](https://github.com/orgs/Blueprints-org/discussions) page.

## Disclaimer

Blueprints is an open source engineering tool that continues to benefit from the collaboration of many contributors. Although efforts have been
made to ensure the that relevant engineering theories have been correctly implemented, it remains the user's responsibility to confirm and accept
the output. Refer to the [license](LICENSE) for clarification of the conditions of use.
